@@ -9,22 +9,22 @@ import (
 
 	clusterclientset "github.com/open-cluster-management/api/client/cluster/clientset/versioned"
 	clusterv1alpha1 "github.com/open-cluster-management/api/cluster/v1alpha1"
-	"github.com/open-cluster-management/multicloud-operators-foundation/cmd/agent/app"
-	"github.com/open-cluster-management/multicloud-operators-foundation/cmd/agent/app/options"
-	actionv1beta1 "github.com/open-cluster-management/multicloud-operators-foundation/pkg/apis/action/v1beta1"
-	clusterv1beta1 "github.com/open-cluster-management/multicloud-operators-foundation/pkg/apis/internal.open-cluster-management.io/v1beta1"
-	viewv1beta1 "github.com/open-cluster-management/multicloud-operators-foundation/pkg/apis/view/v1beta1"
-	actionctrl "github.com/open-cluster-management/multicloud-operators-foundation/pkg/klusterlet/action"
-	clusterclaimctl "github.com/open-cluster-management/multicloud-operators-foundation/pkg/klusterlet/clusterclaim"
-	clusterinfoctl "github.com/open-cluster-management/multicloud-operators-foundation/pkg/klusterlet/clusterinfo"
-	leasectrl "github.com/open-cluster-management/multicloud-operators-foundation/pkg/klusterlet/lease"
-	viewctrl "github.com/open-cluster-management/multicloud-operators-foundation/pkg/klusterlet/view"
-	restutils "github.com/open-cluster-management/multicloud-operators-foundation/pkg/utils/rest"
 	routev1 "github.com/openshift/client-go/route/clientset/versioned"
 	"github.com/spf13/pflag"
+	"github.com/stolostron/multicloud-operators-foundation/cmd/agent/app"
+	"github.com/stolostron/multicloud-operators-foundation/cmd/agent/app/options"
+	actionv1beta1 "github.com/stolostron/multicloud-operators-foundation/pkg/apis/action/v1beta1"
+	clusterv1beta1 "github.com/stolostron/multicloud-operators-foundation/pkg/apis/internal.open-cluster-management.io/v1beta1"
+	viewv1beta1 "github.com/stolostron/multicloud-operators-foundation/pkg/apis/view/v1beta1"
+	actionctrl "github.com/stolostron/multicloud-operators-foundation/pkg/klusterlet/action"
+	clusterclaimctl "github.com/stolostron/multicloud-operators-foundation/pkg/klusterlet/clusterclaim"
+	clusterinfoctl "github.com/stolostron/multicloud-operators-foundation/pkg/klusterlet/clusterinfo"
+	leasectrl "github.com/stolostron/multicloud-operators-foundation/pkg/klusterlet/lease"
+	viewctrl "github.com/stolostron/multicloud-operators-foundation/pkg/klusterlet/view"
+	restutils "github.com/stolostron/multicloud-operators-foundation/pkg/utils/rest"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/util/wait"
-	cacheddiscovery "k8s.io/client-go/discovery/cached"
+
 	"k8s.io/client-go/dynamic"
 	"k8s.io/client-go/kubernetes"
 	clientgoscheme "k8s.io/client-go/kubernetes/scheme"
@@ -33,6 +33,7 @@ import (
 	"k8s.io/client-go/tools/clientcmd"
 	"k8s.io/client-go/tools/leaderelection"
 	ctrl "sigs.k8s.io/controller-runtime"
+	"sigs.k8s.io/controller-runtime/pkg/client/apiutil"
 	ctrlruntimelog "sigs.k8s.io/controller-runtime/pkg/log"
 	"sigs.k8s.io/controller-runtime/pkg/log/zap"
 	"sigs.k8s.io/controller-runtime/pkg/manager/signals"
@@ -78,6 +79,9 @@ func startManager(o *options.AgentOptions, stopCh <-chan struct{}) {
 		setupLog.Error(err, "Unable to get managed cluster kube config.")
 		os.Exit(1)
 	}
+	managedClusterConfig.QPS = o.QPS
+	managedClusterConfig.Burst = o.Burst
+
 	managedClusterDynamicClient, err := dynamic.NewForConfig(managedClusterConfig)
 	if err != nil {
 		setupLog.Error(err, "Unable to create managed cluster dynamic client.")
@@ -105,6 +109,11 @@ func startManager(o *options.AgentOptions, stopCh <-chan struct{}) {
 		os.Exit(1)
 	}
 
+	restMapper, err := apiutil.NewDynamicRESTMapper(managedClusterConfig, apiutil.WithLazyDiscovery)
+	if err != nil {
+		setupLog.Error(err, "Unable to create restmapper.")
+		os.Exit(1)
+	}
 	mgr, err := ctrl.NewManager(hubConfig, ctrl.Options{
 		Scheme:             scheme,
 		MetricsBindAddress: o.MetricsAddr,
@@ -136,18 +145,13 @@ func startManager(o *options.AgentOptions, stopCh <-chan struct{}) {
 			os.Exit(1)
 		}
 
-		// run mapper
-		discoveryClient := cacheddiscovery.NewMemCacheClient(managedClusterClient.Discovery())
-		mapper := restutils.NewMapper(discoveryClient, stopCh)
-		mapper.Run()
-
 		// Add controller into manager
 		actionReconciler := actionctrl.NewActionReconciler(
 			mgr.GetClient(),
 			ctrl.Log.WithName("controllers").WithName("ManagedClusterAction"),
 			mgr.GetScheme(),
 			managedClusterDynamicClient,
-			restutils.NewKubeControl(mapper, managedClusterConfig),
+			restutils.NewKubeControl(restMapper, managedClusterConfig),
 			o.EnableImpersonation,
 		)
 		viewReconciler := &viewctrl.ViewReconciler{
@@ -155,7 +159,7 @@ func startManager(o *options.AgentOptions, stopCh <-chan struct{}) {
 			Log:                         ctrl.Log.WithName("controllers").WithName("ManagedClusterView"),
 			Scheme:                      mgr.GetScheme(),
 			ManagedClusterDynamicClient: managedClusterDynamicClient,
-			Mapper:                      mapper,
+			Mapper:                      restMapper,
 		}
 
 		clusterInfoReconciler := clusterinfoctl.ClusterInfoReconciler{
