@@ -8,8 +8,8 @@ import (
 	"os"
 	"time"
 
-	"github.com/open-cluster-management/multicloud-operators-foundation/cmd/controller/app"
-	"github.com/open-cluster-management/multicloud-operators-foundation/cmd/controller/app/options"
+	"github.com/stolostron/multicloud-operators-foundation/cmd/controller/app"
+	"github.com/stolostron/multicloud-operators-foundation/cmd/controller/app/options"
 	"sigs.k8s.io/controller-runtime/pkg/manager/signals"
 
 	"k8s.io/component-base/cli/flag"
