@@ -8,12 +8,15 @@ import (
 	"strings"
 	"time"
 
+	"k8s.io/apimachinery/pkg/api/equality"
+	"k8s.io/client-go/util/retry"
+
 	metal3v1alpha1 "github.com/metal3-io/baremetal-operator/pkg/apis/metal3/v1alpha1"
-	inventoryv1alpha1 "github.com/open-cluster-management/multicloud-operators-foundation/pkg/apis/inventory/v1alpha1"
-	bmaerrors "github.com/open-cluster-management/multicloud-operators-foundation/pkg/controllers/inventory/errors"
 	objectreferencesv1 "github.com/openshift/custom-resource-status/objectreferences/v1"
 	hivev1 "github.com/openshift/hive/pkg/apis/hive/v1"
 	hiveinternalv1alpha1 "github.com/openshift/hive/pkg/apis/hiveinternal/v1alpha1"
+	inventoryv1alpha1 "github.com/stolostron/multicloud-operators-foundation/pkg/apis/inventory/v1alpha1"
+	bmaerrors "github.com/stolostron/multicloud-operators-foundation/pkg/controllers/inventory/errors"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/api/meta"
@@ -30,7 +33,7 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 	"sigs.k8s.io/controller-runtime/pkg/source"
 
-	k8slabels "github.com/open-cluster-management/multicloud-operators-foundation/pkg/utils"
+	k8slabels "github.com/stolostron/multicloud-operators-foundation/pkg/utils"
 )
 
 const (
@@ -42,8 +45,6 @@ const (
 	ClusterDeploymentNamespaceLabel = "metal3.io/cluster-deployment-namespace"
 	// BareMetalHostKind contains the value of kind BareMetalHost
 	BareMetalHostKind = "BareMetalHost"
-	// BareMetalAssetFinalizer is the finalizer used on BareMetalAsset resource
-	BareMetalAssetFinalizer = "baremetalasset.inventory.open-cluster-management.io"
 )
 
 const (
@@ -52,7 +53,11 @@ const (
 )
 
 func SetupWithManager(mgr manager.Manager) error {
-	if err := add(mgr, newReconciler(mgr)); err != nil {
+	if err := addBMAReconciler(mgr, newBMAReconciler(mgr)); err != nil {
+		klog.Errorf("Failed to create baremetalasset controller, %v", err)
+		return err
+	}
+	if err := addCDReconciler(mgr, newCDReconciler(mgr)); err != nil {
 		klog.Errorf("Failed to create baremetalasset controller, %v", err)
 		return err
 	}
@@ -60,12 +65,12 @@ func SetupWithManager(mgr manager.Manager) error {
 }
 
 // newReconciler returns a new reconcile.Reconciler
-func newReconciler(mgr manager.Manager) reconcile.Reconciler {
+func newBMAReconciler(mgr manager.Manager) reconcile.Reconciler {
 	return &ReconcileBareMetalAsset{client: mgr.GetClient(), scheme: mgr.GetScheme()}
 }
 
 // add adds a new Controller to mgr with r as the reconcile.Reconciler
-func add(mgr manager.Manager, r reconcile.Reconciler) error {
+func addBMAReconciler(mgr manager.Manager, r reconcile.Reconciler) error {
 	// Create a new controller
 	c, err := controller.New("baremetalasset-controller", mgr, controller.Options{Reconciler: r})
 	if err != nil {
@@ -238,17 +243,12 @@ func (r *ReconcileBareMetalAsset) Reconcile(request reconcile.Request) (reconcil
 	} else {
 		// The object is being deleted
 		if contains(instance.GetFinalizers(), BareMetalAssetFinalizer) {
-			if err := r.removeClusterDeploymentFinalizer(instance); err != nil {
-				return reconcile.Result{}, err
-			}
 			return r.deleteSyncSet(instance)
 		}
 		return reconcile.Result{}, nil
 	}
 
-	instance.Status = inventoryv1alpha1.BareMetalAssetStatus{}
 	for _, f := range []func(*inventoryv1alpha1.BareMetalAsset) error{
-		r.checkDeletingClusterDeployment,
 		r.ensureLabels,
 		r.checkAssetSecret,
 		r.cleanupOldHiveSyncSet,
@@ -260,17 +260,16 @@ func (r *ReconcileBareMetalAsset) Reconcile(request reconcile.Request) (reconcil
 			switch {
 			case bmaerrors.IsNoClusterError(err):
 				klog.Info("No cluster specified")
-				return reconcile.Result{}, r.client.Status().Update(context.TODO(), instance)
+				return reconcile.Result{}, r.updateStatus(instance)
 			case bmaerrors.IsAssetSecretNotFoundError(err):
 				// since we won't be notified when the secret is created, requeue after some time
 				klog.Infof("Secret not found, RequeueAfter.Duration %v seconds", assetSecretRequeueAfter)
 				return reconcile.Result{RequeueAfter: time.Duration(assetSecretRequeueAfter) * time.Second},
-					r.client.Status().Update(context.TODO(), instance)
+					r.updateStatus(instance)
 			}
 
 			klog.Errorf("Failed reconcile, %v", err)
-			statusErr := r.client.Status().Update(context.TODO(), instance)
-			if statusErr != nil {
+			if statusErr := r.updateStatus(instance); statusErr != nil {
 				klog.Errorf("Failed to update status, %v", statusErr)
 			}
 
@@ -279,7 +278,26 @@ func (r *ReconcileBareMetalAsset) Reconcile(request reconcile.Request) (reconcil
 	}
 
 	klog.Info("BareMetalAsset Reconciled")
-	return reconcile.Result{}, r.client.Status().Update(context.TODO(), instance)
+	return reconcile.Result{}, r.updateStatus(instance)
+}
+
+func (r *ReconcileBareMetalAsset) updateStatus(instance *inventoryv1alpha1.BareMetalAsset) error {
+	err := retry.RetryOnConflict(retry.DefaultBackoff, func() error {
+		newInstance := &inventoryv1alpha1.BareMetalAsset{}
+		err := r.client.Get(context.TODO(), types.NamespacedName{Name: instance.Name, Namespace: instance.Namespace}, newInstance)
+		if err != nil {
+			if errors.IsNotFound(err) {
+				return nil
+			}
+			return err
+		}
+		if equality.Semantic.DeepEqual(newInstance.Status, instance.Status) {
+			return nil
+		}
+		newInstance.Status = instance.Status
+		return r.client.Status().Update(context.TODO(), newInstance)
+	})
+	return err
 }
 
 // checkAssetSecret verifies that we can find the secret listed in the BareMetalAsset
@@ -588,65 +606,6 @@ func newBareMetalHost(instance *inventoryv1alpha1.BareMetalAsset, assetSyncCompl
 	return bmhJSON, nil
 }
 
-// If related cluster deploymentt is deleting, clean the ref to cluster deployment
-func (r *ReconcileBareMetalAsset) checkDeletingClusterDeployment(instance *inventoryv1alpha1.BareMetalAsset) error {
-	clusterDeploymentName := instance.Spec.ClusterDeployment.Name
-	clusterDeploymentNamespace := instance.Spec.ClusterDeployment.Namespace
-
-	if clusterDeploymentName == "" || clusterDeploymentNamespace == "" {
-		return nil
-	}
-
-	cd := &hivev1.ClusterDeployment{}
-	err := r.client.Get(
-		context.TODO(), types.NamespacedName{Name: clusterDeploymentName, Namespace: clusterDeploymentNamespace}, cd)
-	if err != nil {
-		return nil
-	}
-	if !cd.GetDeletionTimestamp().IsZero() {
-		instanceCopy := instance.DeepCopy()
-		instanceCopy.Spec.ClusterDeployment.Name = ""
-		instanceCopy.Spec.ClusterDeployment.Namespace = ""
-		cd.ObjectMeta.Finalizers = remove(cd.ObjectMeta.Finalizers, BareMetalAssetFinalizer)
-
-		err = r.client.Update(context.TODO(), cd)
-		if err != nil {
-			return err
-		}
-		return r.client.Update(context.TODO(), instanceCopy)
-	}
-
-	if !contains(cd.GetFinalizers(), BareMetalAssetFinalizer) {
-		klog.Info("Finalizer not found for ClusterDeployment. Adding finalizer")
-		cd.ObjectMeta.Finalizers = append(cd.ObjectMeta.Finalizers, BareMetalAssetFinalizer)
-		return r.client.Update(context.TODO(), cd)
-	}
-	return nil
-}
-
-func (r *ReconcileBareMetalAsset) removeClusterDeploymentFinalizer(instance *inventoryv1alpha1.BareMetalAsset) error {
-	if instance.Spec.ClusterDeployment.Namespace == "" && instance.Spec.ClusterDeployment.Name == "" {
-		return nil
-	}
-
-	cd := &hivev1.ClusterDeployment{}
-	err := r.client.Get(
-		context.TODO(), types.NamespacedName{Name: instance.Spec.ClusterDeployment.Name, Namespace: instance.Spec.ClusterDeployment.Namespace}, cd)
-	if errors.IsNotFound(err) {
-		return nil
-	}
-	if err != nil {
-		return err
-	}
-
-	if !contains(cd.GetFinalizers(), BareMetalAssetFinalizer) {
-		return nil
-	}
-
-	cd.ObjectMeta.Finalizers = remove(cd.ObjectMeta.Finalizers, BareMetalAssetFinalizer)
-	return r.client.Update(context.TODO(), cd)
-}
-
 func (r *ReconcileBareMetalAsset) checkHiveClusterSync(instance *inventoryv1alpha1.BareMetalAsset) bool {
 	//get related syncSet
 	syncSetNsN := types.NamespacedName{
