@@ -8,7 +8,7 @@ import (
 	"github.com/onsi/ginkgo"
 	"github.com/onsi/gomega"
 
-	"github.com/open-cluster-management/multicloud-operators-foundation/test/e2e/util"
+	"github.com/stolostron/multicloud-operators-foundation/test/e2e/util"
 
 	hiveclient "github.com/openshift/hive/pkg/client/clientset/versioned"
 	"k8s.io/client-go/dynamic"
